
AWSM Configuration File Reference
=================================
The AWSM config file is a combination of SMRF and AWSM's own configuration
files. Pleas refer to the `Reference for SMRF Configuration Files`_ for any
questions regarding the configuration file sections from SMRF which are as
follows:

* topo
* time
* stations
* csv
* gridded
* air_temperature
* vapor pressure
* wind
* precip
* albedo
* thermal
* soil_temp
* output
* logging
* system

.. _Reference for SMRF Configuration Files: http://smrf.readthedocs.io/en/latest/auto_config.html

All other sections and details for AWSM configuration files can be seen in the
below.

.. include:: ./auto_config.rst
